// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KFILEMETADATA_VERSION_H
#define KFILEMETADATA_VERSION_H

#define KFILEMETADATA_VERSION_STRING "6.23.0"
#define KFILEMETADATA_VERSION_MAJOR 6
#define KFILEMETADATA_VERSION_MINOR 23
#define KFILEMETADATA_VERSION_PATCH 0
#define KFILEMETADATA_VERSION ((6<<16)|(23<<8)|(0))

#endif
